<?php

namespace Drupal\tacjs\Form\Steps;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Class ManageDialog.
 *
 * @package Drupal\tacjs\Form
 */
class ManageDialog extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'tacjs_manage_dialog';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['tacjs.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('tacjs.settings');

    $form['cookieName'] = [
      '#type' => 'textfield',
      '#title' => t('Cookie Name'),
      '#default_value' => $config->get('dialog.cookieName'),
    ];

    $form['hashtag'] = [
      '#type' => 'textfield',
      '#title' => t('Hashtag'),
      '#default_value' => $config->get('dialog.hashtag'),
      '#description' => t('Open the cookies management panel with this hashtag. e.g: <a href=":hashtag">:hashtag</a>.', [':hashtag' => Url::fromRoute('<front>', [], ['absolute' => TRUE, 'fragment' => substr($config->get('dialog.hashtag'), 1)])->toString()]),
    ];

    $form['dialog'] = [
      '#type' => 'vertical_tabs',
      '#title' => $this->t('Dialog Settings'),
    ];

    $form['banner'] = [
      '#type' => 'details',
      '#title' => $this->t('Cookie Banner'),
      '#group' => 'dialog',
    ];
    $form['banner']['orientation'] = [
      '#type' => 'radios',
      '#title' => t('Banner position'),
      '#default_value' => $config->get('dialog.orientation'),
      '#description' => t('Set the position of the cookie consent bar on your website.'),
      '#options' => [
        'top' => t('Top'),
        'bottom' => t('Bottom'),
      ],
    ];

    $form['banner']['showAlertSmall'] = [
      '#type' => 'checkbox',
      '#title' => t('Show the small banner'),
      '#default_value' => $config->get('dialog.showAlertSmall'),
      '#description' => t('Display the manage service small banner on bottom right.'),
    ];

    $form['banner']['cookieslist'] = [
      '#type' => 'checkbox',
      '#title' => t('Show the cookies list'),
      '#default_value' => $config->get('dialog.cookieslist'),
      '#states' => [
        'visible' => [
          ':input[name="showAlertSmall"]' => ['checked' => TRUE],
        ],
      ]
    ];

    $form['banner']['adblocker'] = [
      '#type' => 'checkbox',
      '#title' => t('Warn on Adblocker Detection'),
      '#default_value' => $config->get('dialog.adblocker'),
      '#description' => t('Display a warning if an adblocker is detected.'),
    ];

    $form['banner']['highPrivacy'] = [
      '#type' => 'checkbox',
      '#title' => t('Disable auto consent'),
      '#default_value' => $config->get('dialog.highPrivacy'),
      '#description' => t('Turn this on to disable cookies unless the user expressly chooses to enable them.'),
    ];

    $form['banner']['AcceptAllCta'] = [
      '#type' => 'checkbox',
      '#title' => t('Show Accept All'),
      '#default_value' => $config->get('dialog.AcceptAllCta'),
      '#description' => t('Display the accept all cookies button.'),
      '#states' => [
        'visible' => [
          ':input[name="highPrivacy"]' => ['checked' => TRUE],
        ],
      ]
    ];

    $form['banner']['handleBrowserDNTRequest'] = [
      '#type' => 'checkbox',
      '#title' => t('Respect Do Not Track'),
      '#default_value' => $config->get('dialog.handleBrowserDNTRequest'),
      '#description' => t('If "Do Not Track" is on, disallow all.'),
    ];

    $form['banner']['useExternalCss'] = [
      '#type' => 'checkbox',
      '#title' => t('Use external CSS.'),
      '#default_value' => $config->get('dialog.useExternalCss'),
      '#description' => t('Use external CSS. If false, the tarteaucitron.css file will be loaded.'),
    ];

    $form['banner']['removeCredit'] = [
      '#type' => 'checkbox',
      '#title' => t('Remove credit link.'),
      '#default_value' => $config->get('dialog.removeCredit'),
    ];

    $form['policy']['privacyurl'] = [
      '#type' => 'textfield',
      '#title' => t('Privacy Policy URL'),
      '#default_value' => $config->get('dialog.privacyurl'),
      '#description' => t('Set the URL address of your website privacy policy.'),
    ];

    $form['policy'] = [
      '#type' => 'details',
      '#title' => $this->t('Cookie Policy'),
      '#group' => 'dialog',
    ];

    $form['policy']['readmoreLink'] = [
      '#type' => 'textfield',
      '#title' => t('Read More Link'),
      '#default_value' => $config->get('dialog.readmoreLink'),
      '#description' => t('Change the default read more link.'),
    ];

    $form['policy']['moreInfoLink'] = [
      '#type' => 'checkbox',
      '#title' => t('Show more info link.'),
      '#default_value' => $config->get('dialog.moreInfoLink'),
      '#description' => t('Display services more info link. e.g: <a href=":facebook">:facebook</a>.', [':facebook' => Url::fromUri('https://opt-out.ferank.eu/en/service/facebook/')->toString()]),
    ];

    $form['policy']['cookieDomain'] = [
      '#type' => 'textarea',
      '#title' => t('Domains'),
      '#default_value' => $config->get('dialog.cookieDomain'),
      '#description' => t('Shared cookie for multisite. Enter a list of domains separated by commas.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('tacjs.settings');

    $config
      ->set('dialog.adblocker', $form_state->getValue('adblocker') ? TRUE : FALSE)
      ->set('dialog.hashtag', $form_state->getValue('hashtag'))
      ->set('dialog.cookieName', $form_state->getValue('cookieName'))
      ->set('dialog.highPrivacy', $form_state->getValue('highPrivacy') ? TRUE : FALSE)
      ->set('dialog.orientation', $form_state->getValue('orientation'))
      ->set('dialog.removeCredit', $form_state->getValue('removeCredit') ? TRUE : FALSE)
      ->set('dialog.showAlertSmall', $form_state->getValue('showAlertSmall') ? TRUE : FALSE)
      ->set('dialog.cookieslist', $form_state->getValue('cookieslist') ? TRUE : FALSE)
      ->set('dialog.handleBrowserDNTRequest', $form_state->getValue('handleBrowserDNTRequest') ? TRUE : FALSE)
      ->set('dialog.AcceptAllCta', $form_state->getValue('AcceptAllCta') ? TRUE : FALSE)
      ->set('dialog.moreInfoLink', $form_state->getValue('moreInfoLink') ? TRUE : FALSE)
      ->set('dialog.privacyurl', $form_state->getValue('privacyurl'))
      ->set('dialog.useExternalCss', $form_state->getValue('useExternalCss') ? TRUE : FALSE)
      ->set('dialog.readmoreLink', $form_state->getValue('readmoreLink'))
      ->set('dialog.cookieDomain', $form_state->getValue('cookieDomain'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
